==> sinosun-ui-0.1.9.tgz: package/es/stepper/index.js <==
import "./index.less";
import Icon from '../icon';
import Button from '../button';
import Collapse from '../collapse';
var CollapsePanel = Collapse.Panel;
var stepper = {
    props: {
        mode: {
            type: String, //horizontal（水平）;  vertical（垂直）;
            'default': "horizontal"
        },
        maxSize: {
            type: Number,
            'default': Infinity
        },
        delType: {
            type: String,
            'default': "minus"
        },
        addType: {
            type: String,
            'default': "plus"
        },
        title: {
            type: String,
            'default': ""
        },
        value: {}
    },
    data: function data() {
        return {
            collapse1: ["1"],
            size: 1,
            list: []
        };
    },
    created: function created() {
        // this.list = Array.from(this.value);
    },

    methods: {
        handleRemove: function handleRemove(index) {
            this.size--;
            this.list = this.list.splice(index, 1);
            this.$emit("input", this.list);
        },
        handleAdd: function handleAdd() {
            this.size++;
        },
        horizontalRender: function horizontalRender() {
            var _this = this;

            var h = this.$createElement;

            var list = Array.from(this.size).map(function (index) {
                return h(
                    'div',
                    { 'class': 'sn-stepper-item', key: index },
                    [_this.$slots['default'] || null, index === _this.size - 1 ? h(Icon, {
                        attrs: { type: _this.delType },
                        'class': 'sn-icon', on: {
                            'click': function click(e) {
                                return _this.handleRemove(index);
                            }
                        }
                    }) : h(Icon, {
                        attrs: { type: _this.addType },
                        'class': 'sn-icon', on: {
                            'click': function click(e) {
                                return _this.handleAdd();
                            }
                        }
                    })]
                );
            });
            return list;
        },
        verticalRender: function verticalRender() {
            var _this2 = this;

            var h = this.$createElement;

            var list = Array.from(this.size).map(function (index) {
                var panelTitle = '' + _this2.title + (index + 1);
                return h(
                    CollapsePanel,
                    {
                        attrs: {
                            name: index,
                            title: panelTitle,
                            'title-style': 'color: #262DD9;',
                            'value-style': 'margin-right: .3rem; color: #E32D2D;'
                        }
                    },
                    [h(Icon, { slot: 'value', attrs: { type: 'minus-circle' }
                    }), _this2.$slots['default'] || null]
                );
            });
            return h(
                Collapse,
                {
                    attrs: { value: this.collapse1 }
                },
                [list]
            );
        }
    },
    render: function render() {
        var _this3 = this;

        var h = arguments[0];

        var stepperCls = ["sn-stepper", 'sn-stepper-' + this.mode];
        var content = null;
        if (this.mode === "horizontal") {
            content = this.horizontalRender();
        } else if (this.mode === "vertical") {
            content = this.verticalRender();
        }
        return h(
            'div',
            { 'class': stepperCls },
            [content, this.mode === "vertical" ? h(
                Button,
                {
                    attrs: { ghost: true, type: 'primary' },
                    on: {
                        'click': function click(e) {
                            return _this3.handleAdd();
                        }
                    }
                },
                [h(Icon, {
                    attrs: { type: this.addType },
                    'class': 'sn-icon' }), '\u589E\u52A0', this.title]
            ) : null]
        );
    }
};

export default stepper;

==> sinosun-ui-0.3.1.tgz: package/es/stepper/index.js <==
import "./index.less";
import Icon from '../icon';
import Button from '../button';
import Collapse from '../collapse';
import CollapsePanel from '../collapse-panel';

var stepper = {
    props: {
        mode: {
            type: String, //horizontal（水平）;  vertical（垂直）;
            'default': "horizontal"
        },
        maxSize: {
            type: Number,
            'default': Infinity
        },
        delType: {
            type: String,
            'default': "minus"
        },
        addType: {
            type: String,
            'default': "plus"
        },
        title: {
            type: String,
            'default': ""
        },
        value: {}
    },
    data: function data() {
        return {
            collapse: [0],
            size: 1,
            list: []
        };
    },
    created: function created() {
        // this.list = Array.from(this.value);
    },

    methods: {
        handleRemove: function handleRemove(index) {
            this.size--;
            this.list = this.list.splice(index, 1);
            this.$emit("input", this.list);
        },
        handleAdd: function handleAdd() {
            this.collapse.push(this.size);
            this.size++;
        },
        change: function change(value) {
            console.log(value);
        },
        horizontalRender: function horizontalRender() {
            var _this = this;

            var h = this.$createElement;

            var list = Array.from(this.size).map(function (index) {
                return h(
                    'div',
                    { 'class': 'sn-stepper-item', key: index },
                    [_this.$slots['default'] || null, index === _this.size - 1 ? h(Icon, {
                        attrs: { type: _this.delType },
                        'class': 'sn-icon', on: {
                            'click': _this.handleRemove.bind(_this, index)
                        }
                    }) : h(Icon, {
                        attrs: { type: _this.addType },
                        'class': 'sn-icon', on: {
                            'click': _this.handleAdd
                        }
                    })]
                );
            });
            return list;
        },
        verticalRender: function verticalRender() {
            var _this2 = this;

            var h = this.$createElement;

            var list = Array.from(this.size).map(function (index) {
                var panelTitle = '' + _this2.title + (index + 1);
                return h(
                    CollapsePanel,
                    {
                        attrs: {
                            name: index,
                            title: panelTitle,
                            'title-style': 'color: #262DD9;',
                            'value-style': 'margin-right: .3rem; color: #E32D2D;'
                        }
                    },
                    [h(Icon, { slot: 'value', attrs: { type: 'minus-circle' },
                        on: {
                            'click': _this2.handleRemove.bind(_this2, index)
                        }
                    }), _this2.$slots['default'] || null]
                );
            });
            return h(
                Collapse,
                {
                    attrs: { value: this.collapse, border: true },
                    on: {
                        'input': function input(value) {
                            return _this2.collapse = value;
                        }
                    }
                },
                [list]
            );
        }
    },
    render: function render() {
        var h = arguments[0];

        var stepperCls = ["sn-stepper", 'sn-stepper-' + this.mode];
        var content = null;
        if (this.mode === "horizontal") {
            content = this.horizontalRender();
        } else if (this.mode === "vertical") {
            content = this.verticalRender();
        }
        return h(
            'div',
            { 'class': stepperCls },
            [content, this.mode === "vertical" ? h(
                Button,
                {
                    attrs: { ghost: true, type: 'primary' },
                    on: {
                        'click': this.handleAdd
                    }
                },
                [h(Icon, {
                    attrs: { type: this.addType },
                    'class': 'sn-icon' }), '\u589E\u52A0', this.title]
            ) : null]
        );
    }
};

export default stepper;
